# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSmoothingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkDiscreteGaussianImageFilterPython
else:
    import _itkDiscreteGaussianImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkVectorImagePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkVariableLengthVectorPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageBoundaryConditionPython

def itkDiscreteGaussianImageFilterIF2IF2_New():
    return itkDiscreteGaussianImageFilterIF2IF2.New()

class itkDiscreteGaussianImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkDiscreteGaussianImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiscreteGaussianImageFilterIF2IF2_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiscreteGaussianImageFilterIF2IF2_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_Clone(self)

    def GetVariance(self):
        r"""GetVariance(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetVariance(self)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetMaximumError(self)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetMaximumKernelWidth(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetMaximumKernelWidth(self, _arg)

    def GetFilterDimensionality(self):
        r"""GetFilterDimensionality(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetFilterDimensionality(self)

    def SetFilterDimensionality(self, _arg):
        r"""
        SetFilterDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetFilterDimensionality(self, _arg)

    def SetInputBoundaryCondition(self, _arg):
        r"""
        SetInputBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIF2 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetInputBoundaryCondition(self, _arg)

    def GetInputBoundaryCondition(self):
        r"""GetInputBoundaryCondition(self) -> itkImageBoundaryConditionIF2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetInputBoundaryCondition(self)

    def SetRealBoundaryCondition(self, _arg):
        r"""
        SetRealBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIF2 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetRealBoundaryCondition(self, _arg)

    def GetRealBoundaryCondition(self):
        r"""GetRealBoundaryCondition(self) -> itkImageBoundaryConditionIF2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetRealBoundaryCondition(self)

    def SetVariance(self, *args):
        r"""
        SetVariance(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        SetVariance(self, v)

        Parameters
        ----------
        v: double const *

        SetVariance(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetVariance(self, *args)

    def SetSigmaArray(self, sigmas):
        r"""
        SetSigmaArray(self, sigmas)

        Parameters
        ----------
        sigmas: itkFixedArrayD2 const &

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetSigmaArray(self, sigmas)

    def SetSigma(self, *args):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: itkFixedArrayD2 const &

        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetSigma(self, *args)

    def GetSigmaArray(self):
        r"""GetSigmaArray(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetSigmaArray(self)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetSigma(self)

    def SetMaximumError(self, *args):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const *

        SetMaximumError(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetMaximumError(self, *args)

    def GetKernelRadius(self, *args):
        r"""
        GetKernelRadius(self, dimension) -> unsigned int

        Parameters
        ----------
        dimension: unsigned int const

        GetKernelRadius(self) -> itkFixedArrayD2
        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetKernelRadius(self, *args)

    def GetKernelSize(self):
        r"""GetKernelSize(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetKernelSize(self)

    def SetUseImageSpacing(self, _arg):
        r"""
        SetUseImageSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetUseImageSpacing(self, _arg)

    def GetUseImageSpacing(self):
        r"""GetUseImageSpacing(self) -> bool"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_GetUseImageSpacing(self)

    def UseImageSpacingOn(self):
        r"""UseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_UseImageSpacingOn(self)

    def UseImageSpacingOff(self):
        r"""UseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_UseImageSpacingOff(self)

    def SetUseImageSpacingOn(self):
        r"""SetUseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetUseImageSpacingOn(self)

    def SetUseImageSpacingOff(self):
        r"""SetUseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_SetUseImageSpacingOff(self)
    OutputHasNumericTraitsCheck = _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkDiscreteGaussianImageFilterPython.delete_itkDiscreteGaussianImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiscreteGaussianImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiscreteGaussianImageFilterIF2IF2

        Create a new object of the class itkDiscreteGaussianImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiscreteGaussianImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiscreteGaussianImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiscreteGaussianImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiscreteGaussianImageFilterIF2IF2 in _itkDiscreteGaussianImageFilterPython:
_itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF2IF2_swigregister(itkDiscreteGaussianImageFilterIF2IF2)

def itkDiscreteGaussianImageFilterIF3IF3_New():
    return itkDiscreteGaussianImageFilterIF3IF3.New()

class itkDiscreteGaussianImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkDiscreteGaussianImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiscreteGaussianImageFilterIF3IF3_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiscreteGaussianImageFilterIF3IF3_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_Clone(self)

    def GetVariance(self):
        r"""GetVariance(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetVariance(self)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetMaximumError(self)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetMaximumKernelWidth(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetMaximumKernelWidth(self, _arg)

    def GetFilterDimensionality(self):
        r"""GetFilterDimensionality(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetFilterDimensionality(self)

    def SetFilterDimensionality(self, _arg):
        r"""
        SetFilterDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetFilterDimensionality(self, _arg)

    def SetInputBoundaryCondition(self, _arg):
        r"""
        SetInputBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIF3 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetInputBoundaryCondition(self, _arg)

    def GetInputBoundaryCondition(self):
        r"""GetInputBoundaryCondition(self) -> itkImageBoundaryConditionIF3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetInputBoundaryCondition(self)

    def SetRealBoundaryCondition(self, _arg):
        r"""
        SetRealBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIF3 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetRealBoundaryCondition(self, _arg)

    def GetRealBoundaryCondition(self):
        r"""GetRealBoundaryCondition(self) -> itkImageBoundaryConditionIF3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetRealBoundaryCondition(self)

    def SetVariance(self, *args):
        r"""
        SetVariance(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        SetVariance(self, v)

        Parameters
        ----------
        v: double const *

        SetVariance(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetVariance(self, *args)

    def SetSigmaArray(self, sigmas):
        r"""
        SetSigmaArray(self, sigmas)

        Parameters
        ----------
        sigmas: itkFixedArrayD3 const &

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetSigmaArray(self, sigmas)

    def SetSigma(self, *args):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: itkFixedArrayD3 const &

        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetSigma(self, *args)

    def GetSigmaArray(self):
        r"""GetSigmaArray(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetSigmaArray(self)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetSigma(self)

    def SetMaximumError(self, *args):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const *

        SetMaximumError(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetMaximumError(self, *args)

    def GetKernelRadius(self, *args):
        r"""
        GetKernelRadius(self, dimension) -> unsigned int

        Parameters
        ----------
        dimension: unsigned int const

        GetKernelRadius(self) -> itkFixedArrayD3
        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetKernelRadius(self, *args)

    def GetKernelSize(self):
        r"""GetKernelSize(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetKernelSize(self)

    def SetUseImageSpacing(self, _arg):
        r"""
        SetUseImageSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetUseImageSpacing(self, _arg)

    def GetUseImageSpacing(self):
        r"""GetUseImageSpacing(self) -> bool"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_GetUseImageSpacing(self)

    def UseImageSpacingOn(self):
        r"""UseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_UseImageSpacingOn(self)

    def UseImageSpacingOff(self):
        r"""UseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_UseImageSpacingOff(self)

    def SetUseImageSpacingOn(self):
        r"""SetUseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetUseImageSpacingOn(self)

    def SetUseImageSpacingOff(self):
        r"""SetUseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_SetUseImageSpacingOff(self)
    OutputHasNumericTraitsCheck = _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkDiscreteGaussianImageFilterPython.delete_itkDiscreteGaussianImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiscreteGaussianImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiscreteGaussianImageFilterIF3IF3

        Create a new object of the class itkDiscreteGaussianImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiscreteGaussianImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiscreteGaussianImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiscreteGaussianImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiscreteGaussianImageFilterIF3IF3 in _itkDiscreteGaussianImageFilterPython:
_itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIF3IF3_swigregister(itkDiscreteGaussianImageFilterIF3IF3)

def itkDiscreteGaussianImageFilterISS2ISS2_New():
    return itkDiscreteGaussianImageFilterISS2ISS2.New()

class itkDiscreteGaussianImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkDiscreteGaussianImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiscreteGaussianImageFilterISS2ISS2_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiscreteGaussianImageFilterISS2ISS2_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_Clone(self)

    def GetVariance(self):
        r"""GetVariance(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetVariance(self)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetMaximumError(self)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetMaximumKernelWidth(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetMaximumKernelWidth(self, _arg)

    def GetFilterDimensionality(self):
        r"""GetFilterDimensionality(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetFilterDimensionality(self)

    def SetFilterDimensionality(self, _arg):
        r"""
        SetFilterDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetFilterDimensionality(self, _arg)

    def SetInputBoundaryCondition(self, _arg):
        r"""
        SetInputBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionISS2 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetInputBoundaryCondition(self, _arg)

    def GetInputBoundaryCondition(self):
        r"""GetInputBoundaryCondition(self) -> itkImageBoundaryConditionISS2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetInputBoundaryCondition(self)

    def SetRealBoundaryCondition(self, _arg):
        r"""
        SetRealBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionISS2 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetRealBoundaryCondition(self, _arg)

    def GetRealBoundaryCondition(self):
        r"""GetRealBoundaryCondition(self) -> itkImageBoundaryConditionISS2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetRealBoundaryCondition(self)

    def SetVariance(self, *args):
        r"""
        SetVariance(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        SetVariance(self, v)

        Parameters
        ----------
        v: double const *

        SetVariance(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetVariance(self, *args)

    def SetSigmaArray(self, sigmas):
        r"""
        SetSigmaArray(self, sigmas)

        Parameters
        ----------
        sigmas: itkFixedArrayD2 const &

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetSigmaArray(self, sigmas)

    def SetSigma(self, *args):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: itkFixedArrayD2 const &

        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetSigma(self, *args)

    def GetSigmaArray(self):
        r"""GetSigmaArray(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetSigmaArray(self)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetSigma(self)

    def SetMaximumError(self, *args):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const *

        SetMaximumError(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetMaximumError(self, *args)

    def GetKernelRadius(self, *args):
        r"""
        GetKernelRadius(self, dimension) -> unsigned int

        Parameters
        ----------
        dimension: unsigned int const

        GetKernelRadius(self) -> itkFixedArrayD2
        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetKernelRadius(self, *args)

    def GetKernelSize(self):
        r"""GetKernelSize(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetKernelSize(self)

    def SetUseImageSpacing(self, _arg):
        r"""
        SetUseImageSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetUseImageSpacing(self, _arg)

    def GetUseImageSpacing(self):
        r"""GetUseImageSpacing(self) -> bool"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_GetUseImageSpacing(self)

    def UseImageSpacingOn(self):
        r"""UseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_UseImageSpacingOn(self)

    def UseImageSpacingOff(self):
        r"""UseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_UseImageSpacingOff(self)

    def SetUseImageSpacingOn(self):
        r"""SetUseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetUseImageSpacingOn(self)

    def SetUseImageSpacingOff(self):
        r"""SetUseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_SetUseImageSpacingOff(self)
    OutputHasNumericTraitsCheck = _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkDiscreteGaussianImageFilterPython.delete_itkDiscreteGaussianImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiscreteGaussianImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiscreteGaussianImageFilterISS2ISS2

        Create a new object of the class itkDiscreteGaussianImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiscreteGaussianImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiscreteGaussianImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiscreteGaussianImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiscreteGaussianImageFilterISS2ISS2 in _itkDiscreteGaussianImageFilterPython:
_itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS2ISS2_swigregister(itkDiscreteGaussianImageFilterISS2ISS2)

def itkDiscreteGaussianImageFilterISS3ISS3_New():
    return itkDiscreteGaussianImageFilterISS3ISS3.New()

class itkDiscreteGaussianImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkDiscreteGaussianImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiscreteGaussianImageFilterISS3ISS3_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiscreteGaussianImageFilterISS3ISS3_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_Clone(self)

    def GetVariance(self):
        r"""GetVariance(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetVariance(self)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetMaximumError(self)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetMaximumKernelWidth(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetMaximumKernelWidth(self, _arg)

    def GetFilterDimensionality(self):
        r"""GetFilterDimensionality(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetFilterDimensionality(self)

    def SetFilterDimensionality(self, _arg):
        r"""
        SetFilterDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetFilterDimensionality(self, _arg)

    def SetInputBoundaryCondition(self, _arg):
        r"""
        SetInputBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionISS3 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetInputBoundaryCondition(self, _arg)

    def GetInputBoundaryCondition(self):
        r"""GetInputBoundaryCondition(self) -> itkImageBoundaryConditionISS3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetInputBoundaryCondition(self)

    def SetRealBoundaryCondition(self, _arg):
        r"""
        SetRealBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionISS3 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetRealBoundaryCondition(self, _arg)

    def GetRealBoundaryCondition(self):
        r"""GetRealBoundaryCondition(self) -> itkImageBoundaryConditionISS3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetRealBoundaryCondition(self)

    def SetVariance(self, *args):
        r"""
        SetVariance(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        SetVariance(self, v)

        Parameters
        ----------
        v: double const *

        SetVariance(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetVariance(self, *args)

    def SetSigmaArray(self, sigmas):
        r"""
        SetSigmaArray(self, sigmas)

        Parameters
        ----------
        sigmas: itkFixedArrayD3 const &

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetSigmaArray(self, sigmas)

    def SetSigma(self, *args):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: itkFixedArrayD3 const &

        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetSigma(self, *args)

    def GetSigmaArray(self):
        r"""GetSigmaArray(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetSigmaArray(self)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetSigma(self)

    def SetMaximumError(self, *args):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const *

        SetMaximumError(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetMaximumError(self, *args)

    def GetKernelRadius(self, *args):
        r"""
        GetKernelRadius(self, dimension) -> unsigned int

        Parameters
        ----------
        dimension: unsigned int const

        GetKernelRadius(self) -> itkFixedArrayD3
        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetKernelRadius(self, *args)

    def GetKernelSize(self):
        r"""GetKernelSize(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetKernelSize(self)

    def SetUseImageSpacing(self, _arg):
        r"""
        SetUseImageSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetUseImageSpacing(self, _arg)

    def GetUseImageSpacing(self):
        r"""GetUseImageSpacing(self) -> bool"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_GetUseImageSpacing(self)

    def UseImageSpacingOn(self):
        r"""UseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_UseImageSpacingOn(self)

    def UseImageSpacingOff(self):
        r"""UseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_UseImageSpacingOff(self)

    def SetUseImageSpacingOn(self):
        r"""SetUseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetUseImageSpacingOn(self)

    def SetUseImageSpacingOff(self):
        r"""SetUseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_SetUseImageSpacingOff(self)
    OutputHasNumericTraitsCheck = _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkDiscreteGaussianImageFilterPython.delete_itkDiscreteGaussianImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiscreteGaussianImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiscreteGaussianImageFilterISS3ISS3

        Create a new object of the class itkDiscreteGaussianImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiscreteGaussianImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiscreteGaussianImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiscreteGaussianImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiscreteGaussianImageFilterISS3ISS3 in _itkDiscreteGaussianImageFilterPython:
_itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterISS3ISS3_swigregister(itkDiscreteGaussianImageFilterISS3ISS3)

def itkDiscreteGaussianImageFilterIUC2IUC2_New():
    return itkDiscreteGaussianImageFilterIUC2IUC2.New()

class itkDiscreteGaussianImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkDiscreteGaussianImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiscreteGaussianImageFilterIUC2IUC2_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiscreteGaussianImageFilterIUC2IUC2_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_Clone(self)

    def GetVariance(self):
        r"""GetVariance(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetVariance(self)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetMaximumError(self)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetMaximumKernelWidth(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetMaximumKernelWidth(self, _arg)

    def GetFilterDimensionality(self):
        r"""GetFilterDimensionality(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetFilterDimensionality(self)

    def SetFilterDimensionality(self, _arg):
        r"""
        SetFilterDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetFilterDimensionality(self, _arg)

    def SetInputBoundaryCondition(self, _arg):
        r"""
        SetInputBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIUC2 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetInputBoundaryCondition(self, _arg)

    def GetInputBoundaryCondition(self):
        r"""GetInputBoundaryCondition(self) -> itkImageBoundaryConditionIUC2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetInputBoundaryCondition(self)

    def SetRealBoundaryCondition(self, _arg):
        r"""
        SetRealBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIUC2 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetRealBoundaryCondition(self, _arg)

    def GetRealBoundaryCondition(self):
        r"""GetRealBoundaryCondition(self) -> itkImageBoundaryConditionIUC2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetRealBoundaryCondition(self)

    def SetVariance(self, *args):
        r"""
        SetVariance(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        SetVariance(self, v)

        Parameters
        ----------
        v: double const *

        SetVariance(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetVariance(self, *args)

    def SetSigmaArray(self, sigmas):
        r"""
        SetSigmaArray(self, sigmas)

        Parameters
        ----------
        sigmas: itkFixedArrayD2 const &

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetSigmaArray(self, sigmas)

    def SetSigma(self, *args):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: itkFixedArrayD2 const &

        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetSigma(self, *args)

    def GetSigmaArray(self):
        r"""GetSigmaArray(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetSigmaArray(self)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetSigma(self)

    def SetMaximumError(self, *args):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD2

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const *

        SetMaximumError(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetMaximumError(self, *args)

    def GetKernelRadius(self, *args):
        r"""
        GetKernelRadius(self, dimension) -> unsigned int

        Parameters
        ----------
        dimension: unsigned int const

        GetKernelRadius(self) -> itkFixedArrayD2
        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetKernelRadius(self, *args)

    def GetKernelSize(self):
        r"""GetKernelSize(self) -> itkFixedArrayD2"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetKernelSize(self)

    def SetUseImageSpacing(self, _arg):
        r"""
        SetUseImageSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetUseImageSpacing(self, _arg)

    def GetUseImageSpacing(self):
        r"""GetUseImageSpacing(self) -> bool"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_GetUseImageSpacing(self)

    def UseImageSpacingOn(self):
        r"""UseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_UseImageSpacingOn(self)

    def UseImageSpacingOff(self):
        r"""UseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_UseImageSpacingOff(self)

    def SetUseImageSpacingOn(self):
        r"""SetUseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetUseImageSpacingOn(self)

    def SetUseImageSpacingOff(self):
        r"""SetUseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_SetUseImageSpacingOff(self)
    OutputHasNumericTraitsCheck = _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkDiscreteGaussianImageFilterPython.delete_itkDiscreteGaussianImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiscreteGaussianImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiscreteGaussianImageFilterIUC2IUC2

        Create a new object of the class itkDiscreteGaussianImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiscreteGaussianImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiscreteGaussianImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiscreteGaussianImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiscreteGaussianImageFilterIUC2IUC2 in _itkDiscreteGaussianImageFilterPython:
_itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC2IUC2_swigregister(itkDiscreteGaussianImageFilterIUC2IUC2)

def itkDiscreteGaussianImageFilterIUC3IUC3_New():
    return itkDiscreteGaussianImageFilterIUC3IUC3.New()

class itkDiscreteGaussianImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkDiscreteGaussianImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiscreteGaussianImageFilterIUC3IUC3_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiscreteGaussianImageFilterIUC3IUC3_Pointer"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_Clone(self)

    def GetVariance(self):
        r"""GetVariance(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetVariance(self)

    def GetMaximumError(self):
        r"""GetMaximumError(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetMaximumError(self)

    def GetMaximumKernelWidth(self):
        r"""GetMaximumKernelWidth(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetMaximumKernelWidth(self)

    def SetMaximumKernelWidth(self, _arg):
        r"""
        SetMaximumKernelWidth(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetMaximumKernelWidth(self, _arg)

    def GetFilterDimensionality(self):
        r"""GetFilterDimensionality(self) -> unsigned int"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetFilterDimensionality(self)

    def SetFilterDimensionality(self, _arg):
        r"""
        SetFilterDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetFilterDimensionality(self, _arg)

    def SetInputBoundaryCondition(self, _arg):
        r"""
        SetInputBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIUC3 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetInputBoundaryCondition(self, _arg)

    def GetInputBoundaryCondition(self):
        r"""GetInputBoundaryCondition(self) -> itkImageBoundaryConditionIUC3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetInputBoundaryCondition(self)

    def SetRealBoundaryCondition(self, _arg):
        r"""
        SetRealBoundaryCondition(self, _arg)

        Parameters
        ----------
        _arg: itkImageBoundaryConditionIUC3 *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetRealBoundaryCondition(self, _arg)

    def GetRealBoundaryCondition(self):
        r"""GetRealBoundaryCondition(self) -> itkImageBoundaryConditionIUC3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetRealBoundaryCondition(self)

    def SetVariance(self, *args):
        r"""
        SetVariance(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetVariance(self, v)

        Parameters
        ----------
        v: double const

        SetVariance(self, v)

        Parameters
        ----------
        v: double const *

        SetVariance(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetVariance(self, *args)

    def SetSigmaArray(self, sigmas):
        r"""
        SetSigmaArray(self, sigmas)

        Parameters
        ----------
        sigmas: itkFixedArrayD3 const &

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetSigmaArray(self, sigmas)

    def SetSigma(self, *args):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: itkFixedArrayD3 const &

        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetSigma(self, *args)

    def GetSigmaArray(self):
        r"""GetSigmaArray(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetSigmaArray(self)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetSigma(self)

    def SetMaximumError(self, *args):
        r"""
        SetMaximumError(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayD3

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const

        SetMaximumError(self, v)

        Parameters
        ----------
        v: double const *

        SetMaximumError(self, v)

        Parameters
        ----------
        v: float const *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetMaximumError(self, *args)

    def GetKernelRadius(self, *args):
        r"""
        GetKernelRadius(self, dimension) -> unsigned int

        Parameters
        ----------
        dimension: unsigned int const

        GetKernelRadius(self) -> itkFixedArrayD3
        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetKernelRadius(self, *args)

    def GetKernelSize(self):
        r"""GetKernelSize(self) -> itkFixedArrayD3"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetKernelSize(self)

    def SetUseImageSpacing(self, _arg):
        r"""
        SetUseImageSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetUseImageSpacing(self, _arg)

    def GetUseImageSpacing(self):
        r"""GetUseImageSpacing(self) -> bool"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_GetUseImageSpacing(self)

    def UseImageSpacingOn(self):
        r"""UseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_UseImageSpacingOn(self)

    def UseImageSpacingOff(self):
        r"""UseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_UseImageSpacingOff(self)

    def SetUseImageSpacingOn(self):
        r"""SetUseImageSpacingOn(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetUseImageSpacingOn(self)

    def SetUseImageSpacingOff(self):
        r"""SetUseImageSpacingOff(self)"""
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_SetUseImageSpacingOff(self)
    OutputHasNumericTraitsCheck = _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkDiscreteGaussianImageFilterPython.delete_itkDiscreteGaussianImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiscreteGaussianImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiscreteGaussianImageFilterIUC3IUC3

        Create a new object of the class itkDiscreteGaussianImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiscreteGaussianImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiscreteGaussianImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiscreteGaussianImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiscreteGaussianImageFilterIUC3IUC3 in _itkDiscreteGaussianImageFilterPython:
_itkDiscreteGaussianImageFilterPython.itkDiscreteGaussianImageFilterIUC3IUC3_swigregister(itkDiscreteGaussianImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def discrete_gaussian_image_filter(*args: itkt.ImageLike,  variance: Union[Sequence[float], float]=..., maximum_error: Union[Sequence[float], float]=..., maximum_kernel_width: int=..., filter_dimensionality: int=..., input_boundary_condition=..., real_boundary_condition: itkt.ImageBoundaryCondition=..., sigma: Union[float, Sequence[float]]=..., sigma_array: Sequence[float]=..., use_image_spacing: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for DiscreteGaussianImageFilter"""
    import itk

    kwarg_typehints = { 'variance':variance,'maximum_error':maximum_error,'maximum_kernel_width':maximum_kernel_width,'filter_dimensionality':filter_dimensionality,'input_boundary_condition':input_boundary_condition,'real_boundary_condition':real_boundary_condition,'sigma':sigma,'sigma_array':sigma_array,'use_image_spacing':use_image_spacing }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.DiscreteGaussianImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def discrete_gaussian_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKSmoothing.DiscreteGaussianImageFilter
    discrete_gaussian_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    discrete_gaussian_image_filter.__doc__ = filter_object.__doc__



